@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Nokia Corporation, all rights reserved.
+ * Copyright (C) 2009 Nokia Corporation.
  *
  * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  *                               <zeeshan.ali@nokia.com>
@@ -27,6 +27,7 @@
 #include <libgupnp-av/gupnp-av.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee.h>
 
 
 #define TYPE_ENDIANNESS (endianness_get_type ())
@@ -82,6 +83,7 @@ typedef struct _RygelTranscodeManagerClass RygelTranscodeManagerClass;
 typedef struct _RygelL16Transcoder RygelL16Transcoder;
 typedef struct _RygelL16TranscoderClass RygelL16TranscoderClass;
 typedef struct _RygelL16TranscoderPrivate RygelL16TranscoderPrivate;
+#define _g_free0(var) (var = (g_free (var), NULL))
 
 #define RYGEL_TYPE_L16_TRANSCODER_BIN (rygel_l16_transcoder_bin_get_type ())
 #define RYGEL_L16_TRANSCODER_BIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_L16_TRANSCODER_BIN, RygelL16TranscoderBin))
@@ -92,16 +94,47 @@ typedef struct _RygelL16TranscoderPrivate RygelL16TranscoderPrivate;
 
 typedef struct _RygelL16TranscoderBin RygelL16TranscoderBin;
 typedef struct _RygelL16TranscoderBinClass RygelL16TranscoderBinClass;
+#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
+typedef struct _RygelMediaObjectPrivate RygelMediaObjectPrivate;
+
+#define RYGEL_TYPE_MEDIA_CONTAINER (rygel_media_container_get_type ())
+#define RYGEL_MEDIA_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_MEDIA_CONTAINER, RygelMediaContainer))
+#define RYGEL_MEDIA_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TYPE_MEDIA_CONTAINER, RygelMediaContainerClass))
+#define RYGEL_IS_MEDIA_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TYPE_MEDIA_CONTAINER))
+#define RYGEL_IS_MEDIA_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TYPE_MEDIA_CONTAINER))
+#define RYGEL_MEDIA_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TYPE_MEDIA_CONTAINER, RygelMediaContainerClass))
+
+typedef struct _RygelMediaContainer RygelMediaContainer;
+typedef struct _RygelMediaContainerClass RygelMediaContainerClass;
+typedef struct _RygelMediaItemPrivate RygelMediaItemPrivate;
+
+#define RYGEL_TYPE_ICON_INFO (rygel_icon_info_get_type ())
+#define RYGEL_ICON_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_ICON_INFO, RygelIconInfo))
+#define RYGEL_ICON_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TYPE_ICON_INFO, RygelIconInfoClass))
+#define RYGEL_IS_ICON_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TYPE_ICON_INFO))
+#define RYGEL_IS_ICON_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TYPE_ICON_INFO))
+#define RYGEL_ICON_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TYPE_ICON_INFO, RygelIconInfoClass))
+
+typedef struct _RygelIconInfo RygelIconInfo;
+typedef struct _RygelIconInfoClass RygelIconInfoClass;
+
+#define RYGEL_TYPE_THUMBNAIL (rygel_thumbnail_get_type ())
+#define RYGEL_THUMBNAIL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TYPE_THUMBNAIL, RygelThumbnail))
+#define RYGEL_THUMBNAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TYPE_THUMBNAIL, RygelThumbnailClass))
+#define RYGEL_IS_THUMBNAIL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TYPE_THUMBNAIL))
+#define RYGEL_IS_THUMBNAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TYPE_THUMBNAIL))
+#define RYGEL_THUMBNAIL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TYPE_THUMBNAIL, RygelThumbnailClass))
+
+typedef struct _RygelThumbnail RygelThumbnail;
+typedef struct _RygelThumbnailClass RygelThumbnailClass;
+#define _gst_object_unref0(var) ((var == NULL) ? NULL : (var = (gst_object_unref (var), NULL)))
+#define _gst_caps_unref0(var) ((var == NULL) ? NULL : (var = (gst_caps_unref (var), NULL)))
 
 typedef enum  {
 	ENDIANNESS_LITTLE = G_LITTLE_ENDIAN,
 	ENDIANNESS_BIG = G_BIG_ENDIAN
 } Endianness;
 
-/**
- * The base Transcoder class. Each implementation derives from it and must
- * at least implement create_source method.
- */
 struct _RygelTranscoder {
 	GObject parent_instance;
 	RygelTranscoderPrivate * priv;
@@ -109,14 +142,11 @@ struct _RygelTranscoder {
 
 struct _RygelTranscoderClass {
 	GObjectClass parent_class;
-	GstElement* (*create_source) (RygelTranscoder* self, GstElement* src, GError** error);
-	GUPnPDIDLLiteResource (*create_resource) (RygelTranscoder* self, RygelMediaItem* item, RygelTranscodeManager* manager, GError** error);
+	GstElement* (*create_source) (RygelTranscoder* self, RygelMediaItem* item, GstElement* src, GError** error);
+	GUPnPDIDLLiteResource* (*add_resource) (RygelTranscoder* self, GUPnPDIDLLiteItem* didl_item, RygelMediaItem* item, RygelTranscodeManager* manager, GError** error);
+	guint (*get_distance) (RygelTranscoder* self, RygelMediaItem* item);
 };
 
-/**
- * Transcoder for linear PCM audio (LPCM). This element uses L16TrancoderBin for
- * actual transcoding.
- */
 struct _RygelL16Transcoder {
 	RygelTranscoder parent_instance;
 	RygelL16TranscoderPrivate * priv;
@@ -130,7 +160,53 @@ struct _RygelL16TranscoderPrivate {
 	Endianness endianness;
 };
 
+struct _RygelMediaObject {
+	GObject parent_instance;
+	RygelMediaObjectPrivate * priv;
+	char* id;
+	char* title;
+	guint64 modified;
+	GeeArrayList* uris;
+	RygelMediaContainer* parent;
+	RygelMediaContainer* parent_ref;
+};
 
+struct _RygelMediaObjectClass {
+	GObjectClass parent_class;
+};
+
+struct _RygelMediaItem {
+	RygelMediaObject parent_instance;
+	RygelMediaItemPrivate * priv;
+	char* author;
+	char* album;
+	char* date;
+	char* upnp_class;
+	char* mime_type;
+	char* dlna_profile;
+	glong size;
+	glong duration;
+	gint bitrate;
+	gint sample_freq;
+	gint bits_per_sample;
+	gint n_audio_channels;
+	gint track_number;
+	gint width;
+	gint height;
+	gint pixel_width;
+	gint pixel_height;
+	gint color_depth;
+	GeeArrayList* thumbnails;
+};
+
+struct _RygelMediaItemClass {
+	RygelMediaObjectClass parent_class;
+	GstElement* (*create_stream_source) (RygelMediaItem* self);
+	gboolean (*should_stream) (RygelMediaItem* self);
+};
+
+
+static gpointer rygel_l16_transcoder_parent_class = NULL;
 
 GType endianness_get_type (void);
 GType rygel_transcoder_get_type (void);
@@ -152,21 +228,28 @@ enum  {
 #define RYGEL_L16_TRANSCODER_AUDIO_RATE "audiorate"
 #define RYGEL_L16_TRANSCODER_CAPS_FILTER "capsfilter"
 #define RYGEL_MEDIA_ITEM_AUDIO_CLASS "object.item.audioItem"
-RygelTranscoder* rygel_transcoder_new (const char* mime_type, const char* dlna_profile, const char* upnp_class);
 RygelTranscoder* rygel_transcoder_construct (GType object_type, const char* mime_type, const char* dlna_profile, const char* upnp_class);
 RygelL16Transcoder* rygel_l16_transcoder_new (Endianness endianness);
 RygelL16Transcoder* rygel_l16_transcoder_construct (GType object_type, Endianness endianness);
-RygelL16Transcoder* rygel_l16_transcoder_new (Endianness endianness);
-RygelL16TranscoderBin* rygel_l16_transcoder_bin_new (GstElement* src, RygelL16Transcoder* transcoder, GError** error);
-RygelL16TranscoderBin* rygel_l16_transcoder_bin_construct (GType object_type, GstElement* src, RygelL16Transcoder* transcoder, GError** error);
+RygelL16TranscoderBin* rygel_l16_transcoder_bin_new (RygelMediaItem* item, GstElement* src, RygelL16Transcoder* transcoder, GError** error);
+RygelL16TranscoderBin* rygel_l16_transcoder_bin_construct (GType object_type, RygelMediaItem* item, GstElement* src, RygelL16Transcoder* transcoder, GError** error);
 GType rygel_l16_transcoder_bin_get_type (void);
-static GstElement* rygel_l16_transcoder_real_create_source (RygelTranscoder* base, GstElement* src, GError** error);
-GUPnPDIDLLiteResource rygel_transcoder_create_resource (RygelTranscoder* self, RygelMediaItem* item, RygelTranscodeManager* manager, GError** error);
-static GUPnPDIDLLiteResource rygel_l16_transcoder_real_create_resource (RygelTranscoder* base, RygelMediaItem* item, RygelTranscodeManager* manager, GError** error);
+static GstElement* rygel_l16_transcoder_real_create_source (RygelTranscoder* base, RygelMediaItem* item, GstElement* src, GError** error);
+GUPnPDIDLLiteResource* rygel_transcoder_add_resource (RygelTranscoder* self, GUPnPDIDLLiteItem* didl_item, RygelMediaItem* item, RygelTranscodeManager* manager, GError** error);
+static GUPnPDIDLLiteResource* rygel_l16_transcoder_real_add_resource (RygelTranscoder* base, GUPnPDIDLLiteItem* didl_item, RygelMediaItem* item, RygelTranscodeManager* manager, GError** error);
+GType rygel_media_container_get_type (void);
+gpointer rygel_icon_info_ref (gpointer instance);
+void rygel_icon_info_unref (gpointer instance);
+GParamSpec* rygel_param_spec_icon_info (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void rygel_value_set_icon_info (GValue* value, gpointer v_object);
+gpointer rygel_value_get_icon_info (const GValue* value);
+GType rygel_icon_info_get_type (void);
+GType rygel_thumbnail_get_type (void);
+#define RYGEL_MEDIA_ITEM_IMAGE_CLASS "object.item.imageItem"
+static guint rygel_l16_transcoder_real_get_distance (RygelTranscoder* base, RygelMediaItem* item);
 GstElement* rygel_gst_utils_create_element (const char* factoryname, const char* name, GError** error);
-static inline void _dynamic_set_caps4 (GstElement* obj, GstCaps* value);
-GstElement* rygel_l16_transcoder_create_encoder (RygelL16Transcoder* self, const char* src_pad_name, const char* sink_pad_name, GError** error);
-static gpointer rygel_l16_transcoder_parent_class = NULL;
+static inline void _dynamic_set_caps5 (GstElement* obj, GstCaps* value);
+GstElement* rygel_l16_transcoder_create_encoder (RygelL16Transcoder* self, RygelMediaItem* item, const char* src_pad_name, const char* sink_pad_name, GError** error);
 static void rygel_l16_transcoder_finalize (GObject* obj);
 
 
@@ -193,18 +276,10 @@ RygelL16Transcoder* rygel_l16_transcoder_construct (GType object_type, Endiannes
 	char* _tmp0_;
 	char* _tmp7_;
 	char* mime_type;
-	_tmp6_ = NULL;
-	_tmp5_ = NULL;
-	_tmp4_ = NULL;
-	_tmp3_ = NULL;
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	_tmp7_ = NULL;
-	mime_type = (_tmp7_ = g_strconcat (_tmp5_ = g_strconcat (_tmp4_ = g_strconcat (_tmp2_ = g_strconcat (_tmp1_ = g_strconcat ("audio/L", _tmp0_ = g_strdup_printf ("%i", RYGEL_L16_TRANSCODER_WIDTH), NULL), ";rate=", NULL), _tmp3_ = g_strdup_printf ("%i", RYGEL_L16_TRANSCODER_FREQUENCY), NULL), ";channels=", NULL), _tmp6_ = g_strdup_printf ("%i", RYGEL_L16_TRANSCODER_CHANNELS), NULL), _tmp6_ = (g_free (_tmp6_), NULL), _tmp5_ = (g_free (_tmp5_), NULL), _tmp4_ = (g_free (_tmp4_), NULL), _tmp3_ = (g_free (_tmp3_), NULL), _tmp2_ = (g_free (_tmp2_), NULL), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp7_);
+	mime_type = (_tmp7_ = g_strconcat (_tmp5_ = g_strconcat (_tmp4_ = g_strconcat (_tmp2_ = g_strconcat (_tmp1_ = g_strconcat ("audio/L", _tmp0_ = g_strdup_printf ("%i", RYGEL_L16_TRANSCODER_WIDTH), NULL), ";rate=", NULL), _tmp3_ = g_strdup_printf ("%i", RYGEL_L16_TRANSCODER_FREQUENCY), NULL), ";channels=", NULL), _tmp6_ = g_strdup_printf ("%i", RYGEL_L16_TRANSCODER_CHANNELS), NULL), _g_free0 (_tmp6_), _g_free0 (_tmp5_), _g_free0 (_tmp4_), _g_free0 (_tmp3_), _g_free0 (_tmp2_), _g_free0 (_tmp1_), _g_free0 (_tmp0_), _tmp7_);
 	self = (RygelL16Transcoder*) rygel_transcoder_construct (object_type, mime_type, "LPCM", RYGEL_MEDIA_ITEM_AUDIO_CLASS);
 	self->priv->endianness = endianness;
-	mime_type = (g_free (mime_type), NULL);
+	_g_free0 (mime_type);
 	return self;
 }
 
@@ -214,40 +289,96 @@ RygelL16Transcoder* rygel_l16_transcoder_new (Endianness endianness) {
 }
 
 
-static GstElement* rygel_l16_transcoder_real_create_source (RygelTranscoder* base, GstElement* src, GError** error) {
+static GstElement* rygel_l16_transcoder_real_create_source (RygelTranscoder* base, RygelMediaItem* item, GstElement* src, GError** error) {
 	RygelL16Transcoder * self;
+	GstElement* result;
 	GError * _inner_error_;
+	RygelL16TranscoderBin* _tmp0_;
 	self = (RygelL16Transcoder*) base;
+	g_return_val_if_fail (item != NULL, NULL);
 	g_return_val_if_fail (src != NULL, NULL);
 	_inner_error_ = NULL;
-	return (GstElement*) rygel_l16_transcoder_bin_new (src, self, &_inner_error_);
-}
-
-
-static GUPnPDIDLLiteResource rygel_l16_transcoder_real_create_resource (RygelTranscoder* base, RygelMediaItem* item, RygelTranscodeManager* manager, GError** error) {
-	RygelL16Transcoder * self;
-	GError * _inner_error_;
-	GUPnPDIDLLiteResource res;
-	self = (RygelL16Transcoder*) base;
-	_inner_error_ = NULL;
-	res = RYGEL_TRANSCODER_CLASS (rygel_l16_transcoder_parent_class)->create_resource (RYGEL_TRANSCODER (self), item, manager, &_inner_error_);
+	_tmp0_ = rygel_l16_transcoder_bin_new (item, src, self, &_inner_error_);
 	if (_inner_error_ != NULL) {
 		g_propagate_error (error, _inner_error_);
-		return;
+		return NULL;
 	}
-	res.sample_freq = RYGEL_L16_TRANSCODER_FREQUENCY;
-	res.n_audio_channels = RYGEL_L16_TRANSCODER_CHANNELS;
-	res.bits_per_sample = RYGEL_L16_TRANSCODER_WIDTH;
-	return res;
+	result = (GstElement*) _tmp0_;
+	return result;
 }
 
 
-static inline void _dynamic_set_caps4 (GstElement* obj, GstCaps* value) {
+static GUPnPDIDLLiteResource* rygel_l16_transcoder_real_add_resource (RygelTranscoder* base, GUPnPDIDLLiteItem* didl_item, RygelMediaItem* item, RygelTranscodeManager* manager, GError** error) {
+	RygelL16Transcoder * self;
+	GUPnPDIDLLiteResource* result;
+	GError * _inner_error_;
+	GUPnPDIDLLiteResource* resource;
+	self = (RygelL16Transcoder*) base;
+	g_return_val_if_fail (didl_item != NULL, NULL);
+	g_return_val_if_fail (item != NULL, NULL);
+	g_return_val_if_fail (manager != NULL, NULL);
+	_inner_error_ = NULL;
+	resource = RYGEL_TRANSCODER_CLASS (rygel_l16_transcoder_parent_class)->add_resource (RYGEL_TRANSCODER (self), didl_item, item, manager, &_inner_error_);
+	if (_inner_error_ != NULL) {
+		g_propagate_error (error, _inner_error_);
+		return NULL;
+	}
+	if (resource == NULL) {
+		result = NULL;
+		_g_object_unref0 (resource);
+		return result;
+	}
+	gupnp_didl_lite_resource_set_sample_freq (resource, RYGEL_L16_TRANSCODER_FREQUENCY);
+	gupnp_didl_lite_resource_set_audio_channels (resource, RYGEL_L16_TRANSCODER_CHANNELS);
+	gupnp_didl_lite_resource_set_bits_per_sample (resource, RYGEL_L16_TRANSCODER_WIDTH);
+	gupnp_didl_lite_resource_set_bitrate (resource, ((RYGEL_L16_TRANSCODER_FREQUENCY * RYGEL_L16_TRANSCODER_CHANNELS) * RYGEL_L16_TRANSCODER_WIDTH) / 8);
+	result = resource;
+	return result;
+}
+
+
+static guint rygel_l16_transcoder_real_get_distance (RygelTranscoder* base, RygelMediaItem* item) {
+	RygelL16Transcoder * self;
+	guint result;
+	guint distance;
+	self = (RygelL16Transcoder*) base;
+	g_return_val_if_fail (item != NULL, 0U);
+	if (g_str_has_prefix (item->upnp_class, RYGEL_MEDIA_ITEM_IMAGE_CLASS)) {
+		result = G_MAXUINT;
+		return result;
+	}
+	distance = 0U;
+	if (g_str_has_prefix (item->upnp_class, RYGEL_MEDIA_ITEM_AUDIO_CLASS)) {
+		distance = 0;
+		if (item->sample_freq > 0) {
+			distance = distance + ((guint) abs (item->sample_freq - RYGEL_L16_TRANSCODER_FREQUENCY));
+		}
+		if (item->n_audio_channels > 0) {
+			distance = distance + ((guint) abs (item->n_audio_channels - RYGEL_L16_TRANSCODER_CHANNELS));
+		}
+		if (item->bits_per_sample > 0) {
+			distance = distance + ((guint) abs (item->bits_per_sample - RYGEL_L16_TRANSCODER_WIDTH));
+		}
+	} else {
+		distance = G_MAXUINT / 2;
+	}
+	result = distance;
+	return result;
+}
+
+
+static gpointer _gst_object_ref0 (gpointer self) {
+	return self ? gst_object_ref (self) : NULL;
+}
+
+
+static inline void _dynamic_set_caps5 (GstElement* obj, GstCaps* value) {
 	g_object_set (obj, "caps", value, NULL);
 }
 
 
-GstElement* rygel_l16_transcoder_create_encoder (RygelL16Transcoder* self, const char* src_pad_name, const char* sink_pad_name, GError** error) {
+GstElement* rygel_l16_transcoder_create_encoder (RygelL16Transcoder* self, RygelMediaItem* item, const char* src_pad_name, const char* sink_pad_name, GError** error) {
+	GstElement* result;
 	GError * _inner_error_;
 	GstElement* convert1;
 	GstElement* resample;
@@ -255,20 +386,13 @@ GstElement* rygel_l16_transcoder_create_encoder (RygelL16Transcoder* self, const
 	GstElement* convert2;
 	GstElement* capsfilter;
 	GstBin* bin;
-	GstElement* _tmp4_;
-	GstElement* _tmp3_;
-	GstElement* _tmp2_;
-	GstElement* _tmp1_;
-	GstElement* _tmp0_;
-	GstCaps* _tmp5_;
+	GstCaps* _tmp0_;
 	GstPad* pad;
 	GstGhostPad* ghost;
-	GstPad* _tmp6_;
-	GstPad* _tmp7_;
-	GstGhostPad* _tmp8_;
-	GstPad* _tmp9_;
-	GstElement* _tmp10_;
+	GstPad* _tmp1_;
+	GstGhostPad* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
+	g_return_val_if_fail (item != NULL, NULL);
 	_inner_error_ = NULL;
 	convert1 = rygel_gst_utils_create_element (RYGEL_L16_TRANSCODER_AUDIO_CONVERT, NULL, &_inner_error_);
 	if (_inner_error_ != NULL) {
@@ -278,56 +402,53 @@ GstElement* rygel_l16_transcoder_create_encoder (RygelL16Transcoder* self, const
 	resample = rygel_gst_utils_create_element (RYGEL_L16_TRANSCODER_AUDIO_RESAMPLE, RYGEL_L16_TRANSCODER_AUDIO_RESAMPLE, &_inner_error_);
 	if (_inner_error_ != NULL) {
 		g_propagate_error (error, _inner_error_);
-		(convert1 == NULL) ? NULL : (convert1 = (gst_object_unref (convert1), NULL));
+		_gst_object_unref0 (convert1);
 		return NULL;
 	}
 	audiorate = rygel_gst_utils_create_element (RYGEL_L16_TRANSCODER_AUDIO_RATE, NULL, &_inner_error_);
 	if (_inner_error_ != NULL) {
 		g_propagate_error (error, _inner_error_);
-		(convert1 == NULL) ? NULL : (convert1 = (gst_object_unref (convert1), NULL));
-		(resample == NULL) ? NULL : (resample = (gst_object_unref (resample), NULL));
+		_gst_object_unref0 (convert1);
+		_gst_object_unref0 (resample);
 		return NULL;
 	}
 	convert2 = rygel_gst_utils_create_element (RYGEL_L16_TRANSCODER_AUDIO_CONVERT, NULL, &_inner_error_);
 	if (_inner_error_ != NULL) {
 		g_propagate_error (error, _inner_error_);
-		(convert1 == NULL) ? NULL : (convert1 = (gst_object_unref (convert1), NULL));
-		(resample == NULL) ? NULL : (resample = (gst_object_unref (resample), NULL));
-		(audiorate == NULL) ? NULL : (audiorate = (gst_object_unref (audiorate), NULL));
+		_gst_object_unref0 (convert1);
+		_gst_object_unref0 (resample);
+		_gst_object_unref0 (audiorate);
 		return NULL;
 	}
 	capsfilter = rygel_gst_utils_create_element (RYGEL_L16_TRANSCODER_CAPS_FILTER, RYGEL_L16_TRANSCODER_CAPS_FILTER, &_inner_error_);
 	if (_inner_error_ != NULL) {
 		g_propagate_error (error, _inner_error_);
-		(convert1 == NULL) ? NULL : (convert1 = (gst_object_unref (convert1), NULL));
-		(resample == NULL) ? NULL : (resample = (gst_object_unref (resample), NULL));
-		(audiorate == NULL) ? NULL : (audiorate = (gst_object_unref (audiorate), NULL));
-		(convert2 == NULL) ? NULL : (convert2 = (gst_object_unref (convert2), NULL));
+		_gst_object_unref0 (convert1);
+		_gst_object_unref0 (resample);
+		_gst_object_unref0 (audiorate);
+		_gst_object_unref0 (convert2);
 		return NULL;
 	}
 	bin = (GstBin*) gst_bin_new ("l16-encoder-bin");
-	_tmp4_ = NULL;
-	_tmp3_ = NULL;
-	_tmp2_ = NULL;
-	_tmp1_ = NULL;
-	_tmp0_ = NULL;
-	gst_bin_add_many (bin, (_tmp0_ = convert1, (_tmp0_ == NULL) ? NULL : gst_object_ref (_tmp0_)), (_tmp1_ = resample, (_tmp1_ == NULL) ? NULL : gst_object_ref (_tmp1_)), (_tmp2_ = audiorate, (_tmp2_ == NULL) ? NULL : gst_object_ref (_tmp2_)), (_tmp3_ = convert2, (_tmp3_ == NULL) ? NULL : gst_object_ref (_tmp3_)), (_tmp4_ = capsfilter, (_tmp4_ == NULL) ? NULL : gst_object_ref (_tmp4_)), NULL);
-	_tmp5_ = NULL;
-	_dynamic_set_caps4 (capsfilter, _tmp5_ = gst_caps_new_simple ("audio/x-raw-int", "channels", G_TYPE_INT, RYGEL_L16_TRANSCODER_CHANNELS, "rate", G_TYPE_INT, RYGEL_L16_TRANSCODER_FREQUENCY, "width", G_TYPE_INT, RYGEL_L16_TRANSCODER_WIDTH, "depth", G_TYPE_INT, RYGEL_L16_TRANSCODER_DEPTH, "signed", G_TYPE_BOOLEAN, RYGEL_L16_TRANSCODER_SIGNED, "endianness", G_TYPE_INT, self->priv->endianness, NULL));
-	(_tmp5_ == NULL) ? NULL : (_tmp5_ = (gst_caps_unref (_tmp5_), NULL));
+	gst_bin_add_many (bin, _gst_object_ref0 (convert1), _gst_object_ref0 (resample), _gst_object_ref0 (audiorate), _gst_object_ref0 (convert2), _gst_object_ref0 (capsfilter), NULL);
+	_dynamic_set_caps5 (capsfilter, _tmp0_ = gst_caps_new_simple ("audio/x-raw-int", "channels", G_TYPE_INT, RYGEL_L16_TRANSCODER_CHANNELS, "rate", G_TYPE_INT, RYGEL_L16_TRANSCODER_FREQUENCY, "width", G_TYPE_INT, RYGEL_L16_TRANSCODER_WIDTH, "depth", G_TYPE_INT, RYGEL_L16_TRANSCODER_DEPTH, "signed", G_TYPE_BOOLEAN, RYGEL_L16_TRANSCODER_SIGNED, "endianness", G_TYPE_INT, self->priv->endianness, NULL));
+	_gst_caps_unref0 (_tmp0_);
 	gst_element_link_many (convert1, resample, audiorate, convert2, capsfilter, NULL);
 	pad = gst_element_get_static_pad (convert1, "sink");
 	ghost = (GstGhostPad*) gst_ghost_pad_new (sink_pad_name, pad);
-	_tmp6_ = NULL;
-	gst_element_add_pad ((GstElement*) bin, (_tmp6_ = (GstPad*) ghost, (_tmp6_ == NULL) ? NULL : gst_object_ref (_tmp6_)));
-	_tmp7_ = NULL;
-	pad = (_tmp7_ = gst_element_get_static_pad (capsfilter, "src"), (pad == NULL) ? NULL : (pad = (gst_object_unref (pad), NULL)), _tmp7_);
-	_tmp8_ = NULL;
-	ghost = (_tmp8_ = (GstGhostPad*) gst_ghost_pad_new (src_pad_name, pad), (ghost == NULL) ? NULL : (ghost = (gst_object_unref (ghost), NULL)), _tmp8_);
-	_tmp9_ = NULL;
-	gst_element_add_pad ((GstElement*) bin, (_tmp9_ = (GstPad*) ghost, (_tmp9_ == NULL) ? NULL : gst_object_ref (_tmp9_)));
-	_tmp10_ = NULL;
-	return (_tmp10_ = (GstElement*) bin, (convert1 == NULL) ? NULL : (convert1 = (gst_object_unref (convert1), NULL)), (resample == NULL) ? NULL : (resample = (gst_object_unref (resample), NULL)), (audiorate == NULL) ? NULL : (audiorate = (gst_object_unref (audiorate), NULL)), (convert2 == NULL) ? NULL : (convert2 = (gst_object_unref (convert2), NULL)), (capsfilter == NULL) ? NULL : (capsfilter = (gst_object_unref (capsfilter), NULL)), (pad == NULL) ? NULL : (pad = (gst_object_unref (pad), NULL)), (ghost == NULL) ? NULL : (ghost = (gst_object_unref (ghost), NULL)), _tmp10_);
+	gst_element_add_pad ((GstElement*) bin, _gst_object_ref0 ((GstPad*) ghost));
+	pad = (_tmp1_ = gst_element_get_static_pad (capsfilter, "src"), _gst_object_unref0 (pad), _tmp1_);
+	ghost = (_tmp2_ = (GstGhostPad*) gst_ghost_pad_new (src_pad_name, pad), _gst_object_unref0 (ghost), _tmp2_);
+	gst_element_add_pad ((GstElement*) bin, _gst_object_ref0 ((GstPad*) ghost));
+	result = (GstElement*) bin;
+	_gst_object_unref0 (convert1);
+	_gst_object_unref0 (resample);
+	_gst_object_unref0 (audiorate);
+	_gst_object_unref0 (convert2);
+	_gst_object_unref0 (capsfilter);
+	_gst_object_unref0 (pad);
+	_gst_object_unref0 (ghost);
+	return result;
 }
 
 
@@ -335,7 +456,8 @@ static void rygel_l16_transcoder_class_init (RygelL16TranscoderClass * klass) {
 	rygel_l16_transcoder_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (RygelL16TranscoderPrivate));
 	RYGEL_TRANSCODER_CLASS (klass)->create_source = rygel_l16_transcoder_real_create_source;
-	RYGEL_TRANSCODER_CLASS (klass)->create_resource = rygel_l16_transcoder_real_create_resource;
+	RYGEL_TRANSCODER_CLASS (klass)->add_resource = rygel_l16_transcoder_real_add_resource;
+	RYGEL_TRANSCODER_CLASS (klass)->get_distance = rygel_l16_transcoder_real_get_distance;
 	G_OBJECT_CLASS (klass)->finalize = rygel_l16_transcoder_finalize;
 }
 
