@@ -24,6 +24,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee.h>
 
 
 #define RYGEL_TYPE_MEDIA_OBJECT (rygel_media_object_get_type ())
@@ -46,16 +47,18 @@ typedef struct _RygelMediaObjectPrivate RygelMediaObjectPrivate;
 
 typedef struct _RygelMediaContainer RygelMediaContainer;
 typedef struct _RygelMediaContainerClass RygelMediaContainerClass;
+#define _g_free0(var) (var = (g_free (var), NULL))
+#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
 
-/**
- * Represents a media object (container and item).
- */
 struct _RygelMediaObject {
 	GObject parent_instance;
 	RygelMediaObjectPrivate * priv;
 	char* id;
 	char* title;
+	guint64 modified;
+	GeeArrayList* uris;
 	RygelMediaContainer* parent;
+	RygelMediaContainer* parent_ref;
 };
 
 struct _RygelMediaObjectClass {
@@ -63,19 +66,44 @@ struct _RygelMediaObjectClass {
 };
 
 
+static gpointer rygel_media_object_parent_class = NULL;
 
 GType rygel_media_object_get_type (void);
 GType rygel_media_container_get_type (void);
 enum  {
 	RYGEL_MEDIA_OBJECT_DUMMY_PROPERTY
 };
-static gpointer rygel_media_object_parent_class = NULL;
+RygelMediaObject* rygel_media_object_construct (GType object_type);
+static GObject * rygel_media_object_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static void rygel_media_object_finalize (GObject* obj);
 
 
 
+RygelMediaObject* rygel_media_object_construct (GType object_type) {
+	RygelMediaObject * self;
+	self = g_object_newv (object_type, 0, NULL);
+	return self;
+}
+
+
+static GObject * rygel_media_object_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
+	GObject * obj;
+	GObjectClass * parent_class;
+	RygelMediaObject * self;
+	parent_class = G_OBJECT_CLASS (rygel_media_object_parent_class);
+	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
+	self = RYGEL_MEDIA_OBJECT (obj);
+	{
+		GeeArrayList* _tmp0_;
+		self->uris = (_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, g_direct_equal), _g_object_unref0 (self->uris), _tmp0_);
+	}
+	return obj;
+}
+
+
 static void rygel_media_object_class_init (RygelMediaObjectClass * klass) {
 	rygel_media_object_parent_class = g_type_class_peek_parent (klass);
+	G_OBJECT_CLASS (klass)->constructor = rygel_media_object_constructor;
 	G_OBJECT_CLASS (klass)->finalize = rygel_media_object_finalize;
 }
 
@@ -87,8 +115,10 @@ static void rygel_media_object_instance_init (RygelMediaObject * self) {
 static void rygel_media_object_finalize (GObject* obj) {
 	RygelMediaObject * self;
 	self = RYGEL_MEDIA_OBJECT (obj);
-	self->id = (g_free (self->id), NULL);
-	self->title = (g_free (self->title), NULL);
+	_g_free0 (self->id);
+	_g_free0 (self->title);
+	_g_object_unref0 (self->uris);
+	_g_object_unref0 (self->parent_ref);
 	G_OBJECT_CLASS (rygel_media_object_parent_class)->finalize (obj);
 }
 
